==> haskell-hls-alternate-number-format-plugin-1.3.0.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-alternate-number-format-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-alternate-number-format-plugin
version:              1.3.0.1
visibility:           public
id:
    hls-alternate-number-format-plugin-1.3.0.1-EZMaWKCMa3iF4WLZwWhc86

key:
    hls-alternate-number-format-plugin-1.3.0.1-EZMaWKCMa3iF4WLZwWhc86

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:
    Provide Alternate Number Formats plugin for Haskell Language Server

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  7cb48683bd4fbc8f7807fa49c1a0203f
exposed:              True
exposed-modules:
    Ide.Plugin.AlternateNumberFormat Ide.Plugin.Conversion

hidden-modules:       Ide.Plugin.Literals
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-alternate-number-format-plugin-1.3.0.1

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-alternate-number-format-plugin-1.3.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-alternate-number-format-plugin
hs-libraries:
    HShls-alternate-number-format-plugin-1.3.0.1-EZMaWKCMa3iF4WLZwWhc86

depends:
    aeson-2.1.2.1-3lugcDour1r4V4jv6ZKvkq base-4.16.4.0
    containers-0.6.5.1 extra-1.7.16-KspoS0yodOb8Msf7MgdZ07
    ghc-boot-th-9.2.8 ghcide-1.10.0.0-8N69zrdFqmeLL7sPaHEIQq
    hie-compat-0.3.0.0-J18lPJVEz9RKJxYK1ST1Nn
    hls-graph-1.9.0.0-FD3Mdyh3kIDFyGjJsBb2ZB
    hls-plugin-api-1.6.0.0-Ca7hbYl2UGtL2lMuiElAIW
    lens-5.2.3-LJCKq2CVV0OBzhsqfjAjcB
    lsp-1.6.0.0-12cisgDKGZpK41czXe4FUp mtl-2.2.2
    regex-tdfa-1.3.2.2-D3LpMz1GC7yHTJs5TZ8Rua
    syb-0.7.2.4-89doc1zYrrWCF1u4CgIEo3 text-1.2.5.0
    unordered-containers-0.2.20-2iyjFoh2jxC3XOaFpxfD6Q

haddock-interfaces:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html/hls-alternate-number-format-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-alternate-number-format-plugin-1.3.0.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-alternate-number-format-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-alternate-number-format-plugin
version:              1.3.0.1
visibility:           public
id:
    hls-alternate-number-format-plugin-1.3.0.1-450B6R49oQGGFejmck8fZD

key:
    hls-alternate-number-format-plugin-1.3.0.1-450B6R49oQGGFejmck8fZD

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:
    Provide Alternate Number Formats plugin for Haskell Language Server

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  09aae1752ed09c2019f4119a83f2f22a
exposed:              True
exposed-modules:
    Ide.Plugin.AlternateNumberFormat Ide.Plugin.Conversion

hidden-modules:       Ide.Plugin.Literals
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-alternate-number-format-plugin-1.3.0.1

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-alternate-number-format-plugin-1.3.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-alternate-number-format-plugin
hs-libraries:
    HShls-alternate-number-format-plugin-1.3.0.1-450B6R49oQGGFejmck8fZD

depends:
    aeson-2.1.2.1-3lugcDour1r4V4jv6ZKvkq base-4.16.4.0
    containers-0.6.5.1 extra-1.7.16-KspoS0yodOb8Msf7MgdZ07
    ghc-boot-th-9.2.8 ghcide-1.10.0.0-8YNBVtwkfPOEXcK9jmX81b
    hie-compat-0.3.0.0-J18lPJVEz9RKJxYK1ST1Nn
    hls-graph-1.9.0.0-FD3Mdyh3kIDFyGjJsBb2ZB
    hls-plugin-api-1.6.0.0-9wGoIV0w1AI6MQx1RgDVdm
    lens-5.2.3-LJCKq2CVV0OBzhsqfjAjcB
    lsp-1.6.0.0-AdGydXppFhq7XJ93v8D4rR mtl-2.2.2
    regex-tdfa-1.3.2.2-D3LpMz1GC7yHTJs5TZ8Rua
    syb-0.7.2.4-89doc1zYrrWCF1u4CgIEo3 text-1.2.5.0
    unordered-containers-0.2.20-2iyjFoh2jxC3XOaFpxfD6Q

haddock-interfaces:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html/hls-alternate-number-format-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
